scDaPars: Use scDaPars to quantify APA dynamics across single cells...

Description Usage Arguments Value Author(s)

View source: R/scDaPars.R

Description

Use scDaPars to quantify APA dynamics across single cells using scRNA-seq data

Usage

1
scDaPars(raw_PDUI_file, out_dir, filter_gene_thre, filter_cell_thre)

Arguments

raw_PDUI_file

A character specifying the full path of the raw PDUI matrix generated by step1 of scDaPars;

out_dir

A character specifying the full path of the output directory;

filter_gene_thr

A number between 0 and 1; specifying the percent of cells a gene's PDUI must be detected;

filter_cell_thr

A number between 0; specigying the percent of genes' PDUI a cell must be detected;

Value

scDaPars returns the imputed PDUI_matrix with rows representing genes and columns representing cells; It saves the imputed PDUI matrix as scDaPars_imputed_results.txt;

Author(s)

Yipeng Gao, yipeng.gao@bcm.edu

Wei Li, wei.li@uci.edu


YiPeng-Gao/scDaPars documentation built on May 29, 2021, 3:18 a.m.