Description Usage Arguments Value Author(s)
Use scDaPars to quantify APA dynamics across single cells using scRNA-seq data
1 | scDaPars(raw_PDUI_file, out_dir, filter_gene_thre, filter_cell_thre)
|
raw_PDUI_file |
A character specifying the full path of the raw PDUI matrix generated by step1 of scDaPars; |
out_dir |
A character specifying the full path of the output directory; |
filter_gene_thr |
A number between 0 and 1; specifying the percent of cells a gene's PDUI must be detected; |
filter_cell_thr |
A number between 0; specigying the percent of genes' PDUI a cell must be detected; |
scDaPars returns the imputed PDUI_matrix with rows representing genes and columns representing cells; It saves the imputed PDUI matrix as scDaPars_imputed_results.txt;
Yipeng Gao, yipeng.gao@bcm.edu
Wei Li, wei.li@uci.edu
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.